@@ -11,35 +11,48 @@ Results:
 import gym
 import tensorflow as tf
 
-from garage.experiment import run_experiment
-from garage.np.exploration_strategies.gaussian_strategy import GaussianStrategy
-from garage.replay_buffer import SimpleReplayBuffer
+from garage import wrap_experiment
+from garage.envs import GarageEnv
+from garage.experiment import LocalTFRunner
+from garage.experiment.deterministic import set_seed
+from garage.np.exploration_policies import AddGaussianNoise
+from garage.replay_buffer import PathBuffer
 from garage.tf.algos import TD3
-from garage.tf.envs import TfEnv
-from garage.tf.experiment import LocalTFRunner
 from garage.tf.policies import ContinuousMLPPolicy
 from garage.tf.q_functions import ContinuousMLPQFunction
 
 
-def run_task(snapshot_config, *_):
+@wrap_experiment(snapshot_mode='last')
+def td3_pendulum(ctxt=None, seed=1):
     """Wrap TD3 training task in the run_task function.
 
     Args:
-        snapshot_config (garage.experiment.SnapshotConfig): Configuration
-            values for snapshotting.
-        *_ (object): Hyperparameters (unused).
+        ctxt (garage.experiment.ExperimentContext): The experiment
+            configuration used by LocalRunner to create the snapshotter.
+        seed (int): Used to seed the random number generator to produce
+            determinism.
 
     """
-    with LocalTFRunner(snapshot_config) as runner:
-        env = TfEnv(gym.make('InvertedDoublePendulum-v2'))
+    set_seed(seed)
+    with LocalTFRunner(ctxt) as runner:
+        n_epochs = 500
+        steps_per_epoch = 20
+        batch_size = 250
+        num_timesteps = n_epochs * steps_per_epoch * batch_size
 
-        action_noise = GaussianStrategy(env.spec, max_sigma=0.1, min_sigma=0.1)
+        env = GarageEnv(gym.make('InvertedDoublePendulum-v2'))
 
         policy = ContinuousMLPPolicy(env_spec=env.spec,
                                      hidden_sizes=[400, 300],
                                      hidden_nonlinearity=tf.nn.relu,
                                      output_nonlinearity=tf.nn.tanh)
 
+        exploration_policy = AddGaussianNoise(env.spec,
+                                              policy,
+                                              total_timesteps=num_timesteps,
+                                              max_sigma=0.1,
+                                              min_sigma=0.1)
+
         qf = ContinuousMLPQFunction(name='ContinuousMLPQFunction',
                                     env_spec=env.spec,
                                     hidden_sizes=[400, 300],
@@ -52,9 +65,7 @@ def run_task(snapshot_config, *_):
                                      action_merge_layer=0,
                                      hidden_nonlinearity=tf.nn.relu)
 
-        replay_buffer = SimpleReplayBuffer(env_spec=env.spec,
-                                           size_in_transitions=int(1e6),
-                                           time_horizon=250)
+        replay_buffer = PathBuffer(capacity_in_transitions=int(1e6))
 
         td3 = TD3(env_spec=env.spec,
                   policy=policy,
@@ -64,22 +75,18 @@ def run_task(snapshot_config, *_):
                   qf2=qf2,
                   replay_buffer=replay_buffer,
                   target_update_tau=1e-2,
-                  n_epoch_cycles=20,
+                  steps_per_epoch=steps_per_epoch,
                   n_train_steps=1,
                   smooth_return=False,
                   discount=0.99,
                   buffer_batch_size=100,
                   min_buffer_size=1e4,
-                  exploration_strategy=action_noise,
-                  policy_optimizer=tf.train.AdamOptimizer,
-                  qf_optimizer=tf.train.AdamOptimizer)
+                  exploration_policy=exploration_policy,
+                  policy_optimizer=tf.compat.v1.train.AdamOptimizer,
+                  qf_optimizer=tf.compat.v1.train.AdamOptimizer)
 
         runner.setup(td3, env)
-        runner.train(n_epochs=500, n_epoch_cycles=20, batch_size=250)
+        runner.train(n_epochs=n_epochs, batch_size=batch_size)
 
 
-run_experiment(
-    run_task,
-    snapshot_mode='last',
-    seed=1,
-)
+td3_pendulum(seed=1)
