@@ -7,6 +7,7 @@ import scipy.stats
 import tensorflow as tf
 
 from garage import InOutSpec, log_performance, TrajectoryBatch
+from garage.experiment import deterministic
 from garage.misc import tensor_utils as np_tensor_utils
 from garage.np.algos import RLAlgorithm
 from garage.sampler import LocalSampler
@@ -128,9 +129,6 @@ class TENPO(RLAlgorithm):
         self._name = name
         self._name_scope = tf.name_scope(self._name)
         self._old_policy = policy.clone('old_policy')
-        self._old_policy.model.parameters = self.policy.model.parameters
-        self._old_policy.encoder.model.parameters = (
-            self.policy.encoder.model.parameters)
         self._use_softplus_entropy = use_softplus_entropy
         self._stop_ce_gradient = stop_ce_gradient
 
@@ -148,8 +146,6 @@ class TENPO(RLAlgorithm):
 
             self._inference = inference
             self._old_inference = inference.clone('old_inference')
-            self._old_inference.model.parameters = (
-                self._inference.model.parameters)
             self.inference_ce_coeff = float(inference_ce_coeff)
             self.inference_optimizer = inference_opt(**inference_opt_args)
             self.encoder_ent_coeff = encoder_ent_coeff
@@ -663,8 +659,9 @@ class TENPO(RLAlgorithm):
             with tf.name_scope('inference_ce'):
                 # Build inference with trajectory windows
 
-                traj_ll = infer_dist.log_prob(enc_dist.sample(),
-                                              name='traj_ll')
+                traj_ll = infer_dist.log_prob(
+                    enc_dist.sample(seed=deterministic.get_tf_seed_stream()),
+                    name='traj_ll')
 
                 inference_ce_raw = -traj_ll
                 inference_ce = tf.clip_by_value(inference_ce_raw, -3, 3)
