@@ -1,4 +1,9 @@
-from garage.tf.models.base import Model
+"""Network Models."""
+from garage.tf.models.categorical_cnn_model import CategoricalCNNModel
+from garage.tf.models.categorical_gru_model import CategoricalGRUModel
+from garage.tf.models.categorical_lstm_model import CategoricalLSTMModel
+from garage.tf.models.categorical_mlp_model import CategoricalMLPModel
+from garage.tf.models.cnn_mlp_merge_model import CNNMLPMergeModel
 from garage.tf.models.cnn_model import CNNModel
 from garage.tf.models.cnn_model_max_pooling import CNNModelWithMaxPooling
 from garage.tf.models.gaussian_cnn_model import GaussianCNNModel
@@ -10,13 +15,17 @@ from garage.tf.models.lstm_model import LSTMModel
 from garage.tf.models.mlp_dueling_model import MLPDuelingModel
 from garage.tf.models.mlp_merge_model import MLPMergeModel
 from garage.tf.models.mlp_model import MLPModel
+from garage.tf.models.model import BaseModel, Model
+from garage.tf.models.module import Module, StochasticModule
 from garage.tf.models.normalized_input_mlp_model import (
     NormalizedInputMLPModel)
 from garage.tf.models.sequential import Sequential
 
 __all__ = [
-    'CNNModel', 'CNNModelWithMaxPooling', 'LSTMModel', 'Model',
+    'BaseModel', 'CategoricalCNNModel', 'CategoricalGRUModel',
+    'CategoricalLSTMModel', 'CategoricalMLPModel', 'CNNMLPMergeModel',
+    'CNNModel', 'CNNModelWithMaxPooling', 'LSTMModel', 'Model', 'Module',
     'GaussianCNNModel', 'GaussianGRUModel', 'GaussianLSTMModel',
     'GaussianMLPModel', 'GRUModel', 'MLPDuelingModel', 'MLPMergeModel',
-    'MLPModel', 'NormalizedInputMLPModel', 'Sequential'
+    'MLPModel', 'NormalizedInputMLPModel', 'Sequential', 'StochasticModule'
 ]
