@@ -1,13 +1,14 @@
 """Create a test that fails when garage.tf.algos.TD3 performance is too low."""
 
 import gym
+import pytest
 import tensorflow as tf
 
-from garage.np.exploration_strategies.gaussian_strategy import GaussianStrategy
-from garage.replay_buffer import SimpleReplayBuffer
+from garage.envs import GarageEnv
+from garage.experiment import LocalTFRunner
+from garage.np.exploration_policies import AddGaussianNoise
+from garage.replay_buffer import PathBuffer
 from garage.tf.algos import TD3
-from garage.tf.envs import TfEnv
-from garage.tf.experiment import LocalTFRunner
 from garage.tf.policies import ContinuousMLPPolicy
 from garage.tf.q_functions import ContinuousMLPQFunction
 from tests.fixtures import snapshot_config, TfGraphTestCase
@@ -16,20 +17,28 @@ from tests.fixtures import snapshot_config, TfGraphTestCase
 class TestTD3(TfGraphTestCase):
     """Tests for TD3 algo."""
 
+    @pytest.mark.mujoco_long
     def test_td3_pendulum(self):
         """Test TD3 with Pendulum environment."""
         with LocalTFRunner(snapshot_config) as runner:
-            env = TfEnv(gym.make('InvertedDoublePendulum-v2'))
+            n_epochs = 10
+            steps_per_epoch = 20
+            batch_size = 250
+            num_timesteps = n_epochs * steps_per_epoch * batch_size
 
-            action_noise = GaussianStrategy(env.spec,
-                                            max_sigma=0.1,
-                                            min_sigma=0.1)
+            env = GarageEnv(gym.make('InvertedDoublePendulum-v2'))
 
             policy = ContinuousMLPPolicy(env_spec=env.spec,
                                          hidden_sizes=[400, 300],
                                          hidden_nonlinearity=tf.nn.relu,
                                          output_nonlinearity=tf.nn.tanh)
 
+            exploration_policy = AddGaussianNoise(env.spec,
+                                                  policy,
+                                                  num_timesteps,
+                                                  max_sigma=0.1,
+                                                  min_sigma=0.1)
+
             qf = ContinuousMLPQFunction(name='ContinuousMLPQFunction',
                                         env_spec=env.spec,
                                         hidden_sizes=[400, 300],
@@ -42,9 +51,7 @@ class TestTD3(TfGraphTestCase):
                                          action_merge_layer=0,
                                          hidden_nonlinearity=tf.nn.relu)
 
-            replay_buffer = SimpleReplayBuffer(env_spec=env.spec,
-                                               size_in_transitions=int(1e6),
-                                               time_horizon=250)
+            replay_buffer = PathBuffer(capacity_in_transitions=int(1e6))
 
             algo = TD3(env_spec=env.spec,
                        policy=policy,
@@ -53,8 +60,8 @@ class TestTD3(TfGraphTestCase):
                        qf=qf,
                        qf2=qf2,
                        replay_buffer=replay_buffer,
+                       steps_per_epoch=steps_per_epoch,
                        target_update_tau=0.005,
-                       n_epoch_cycles=20,
                        n_train_steps=50,
                        discount=0.99,
                        smooth_return=False,
@@ -62,12 +69,11 @@ class TestTD3(TfGraphTestCase):
                        buffer_batch_size=100,
                        policy_weight_decay=0.001,
                        qf_weight_decay=0.001,
-                       exploration_strategy=action_noise,
+                       exploration_policy=exploration_policy,
                        policy_optimizer=tf.compat.v1.train.AdamOptimizer,
                        qf_optimizer=tf.compat.v1.train.AdamOptimizer)
 
             runner.setup(algo, env)
-            last_avg_ret = runner.train(n_epochs=10,
-                                        n_epoch_cycles=20,
-                                        batch_size=250)
+            last_avg_ret = runner.train(n_epochs=n_epochs,
+                                        batch_size=batch_size)
             assert last_avg_ret > 400
